@@ -26,10 +26,8 @@ import java.nio.file.Path;
 import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Collection;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
-import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -64,6 +62,7 @@ import org.eclipse.jdt.core.IPackageFragmentRoot;
 import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
+import org.eclipse.jdt.internal.junit.buildpath.BuildPathSupport;
 import org.eclipse.jdt.internal.junit.launcher.ITestKind;
 import org.eclipse.jdt.internal.junit.launcher.JUnitLaunchConfigurationConstants;
 import org.eclipse.jdt.internal.junit.launcher.JUnitRuntimeClasspathEntry;
@@ -77,19 +76,17 @@ import org.eclipse.jdt.launching.SocketUtil;
 import org.eclipse.jdt.launching.VMRunnerConfiguration;
 import org.eclipse.jdt.ui.unittest.junit.JUnitTestPlugin;
 import org.eclipse.jdt.ui.unittest.junit.JUnitTestPlugin.JUnitVersion;
-import org.eclipse.osgi.service.resolver.BundleDescription;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.pde.core.plugin.IFragmentModel;
 import org.eclipse.pde.core.plugin.IPluginModelBase;
 import org.eclipse.pde.core.plugin.PluginRegistry;
 import org.eclipse.pde.core.plugin.TargetPlatform;
 import org.eclipse.pde.internal.core.ClasspathHelper;
-import org.eclipse.pde.internal.core.DependencyManager;
 import org.eclipse.pde.internal.core.ICoreConstants;
-import org.eclipse.pde.internal.core.PDECore;
 import org.eclipse.pde.internal.core.TargetPlatformHelper;
 import org.eclipse.pde.internal.core.util.CoreUtility;
 import org.eclipse.pde.internal.launching.IPDEConstants;
+import org.eclipse.pde.internal.launching.JUnitLaunchRequirements;
 import org.eclipse.pde.internal.launching.launcher.BundleLauncherHelper;
 import org.eclipse.pde.internal.launching.launcher.EclipsePluginValidationOperation;
 import org.eclipse.pde.internal.launching.launcher.LaunchArgumentsHelper;
@@ -99,7 +96,6 @@ import org.eclipse.pde.internal.launching.launcher.LauncherUtils;
 import org.eclipse.pde.internal.launching.launcher.RequirementHelper;
 import org.eclipse.pde.internal.launching.launcher.VMHelper;
 import org.eclipse.pde.launching.IPDELauncherConstants;
-import org.eclipse.pde.launching.JUnitLaunchConfigurationDelegate;
 import org.eclipse.pde.launching.PDESourcePathProvider;
 import org.eclipse.pde.unittest.junit.JUnitPluginTestPlugin;
 import org.osgi.framework.Bundle;
@@ -161,6 +157,7 @@ public class JUnitPluginLaunchConfigurationDelegate extends AbstractJavaLaunchCo
 		}
 	}
 
+	@SuppressWarnings("restriction")
 	private VMRunnerConfiguration getVMRunnerConfiguration(ILaunchConfiguration configuration, ILaunch launch,
 			String mode, IProgressMonitor monitor) throws CoreException {
 		VMRunnerConfiguration runConfig = null;
@@ -239,14 +236,20 @@ public class JUnitPluginLaunchConfigurationDelegate extends AbstractJavaLaunchCo
 			String[] classpath = classpathAndModulepath[0];
 			String[] modulepath = classpathAndModulepath[1];
 
-			if (junitVersion == JUnitVersion.JUNIT5) {
+			boolean isJUnit5 = junitVersion == JUnitVersion.JUNIT5;
+			boolean isJUnit6 = junitVersion == JUnitVersion.JUNIT6;
+			String junitPlatformVersion = BuildPathSupport.JUNIT6_VERSION;
+			if (isJUnit5) {
+				junitPlatformVersion = BuildPathSupport.JUNIT_PLATFORM_VERSION;
+			}
+			if (isJUnit5 || isJUnit6) {
 				if (!configuration.getAttribute(
 						JUnitLaunchConfigurationConstants.ATTR_DONT_ADD_MISSING_JUNIT5_DEPENDENCY, false)) {
-					if (!Arrays.stream(classpath).anyMatch(
-							s -> s.contains("junit-platform-launcher") || s.contains("org.junit.platform.launcher"))) { //$NON-NLS-1$ //$NON-NLS-2$
+					if (!Arrays.stream(classpath).anyMatch(s -> s.contains(BuildPathSupport.JUNIT_PLATFORM_LAUNCHER)
+							|| s.contains("org.junit.platform.launcher"))) { //$NON-NLS-1$
 						try {
-							JUnitRuntimeClasspathEntry x = new JUnitRuntimeClasspathEntry("junit-platform-launcher", //$NON-NLS-1$
-									null);
+							JUnitRuntimeClasspathEntry x = new JUnitRuntimeClasspathEntry(
+									BuildPathSupport.JUNIT_PLATFORM_LAUNCHER, null, junitPlatformVersion);
 							String entryString = new ClasspathLocalizer(Platform.inDevelopmentMode()).entryString(x);
 							int length = classpath.length;
 							System.arraycopy(classpath, 0, classpath = new String[length + 1], 0, length);
@@ -365,7 +368,7 @@ public class JUnitPluginLaunchConfigurationDelegate extends AbstractJavaLaunchCo
 				LinkedHashMap::new, Collectors.toCollection(ArrayList::new)));
 
 		// implicitly add the plug-ins required for JUnit testing if necessary
-		addRequiredJunitRuntimePlugins(configuration);
+		JUnitLaunchRequirements.addRequiredJunitRuntimePlugins(configuration, fAllBundles, fModels);
 
 		String attribute = launch.getAttribute(PDE_JUNIT_SHOW_COMMAND);
 		boolean isShowCommand = false;
@@ -386,41 +389,6 @@ public class JUnitPluginLaunchConfigurationDelegate extends AbstractJavaLaunchCo
 		synchronizeManifests(configuration, subMonitor.split(1));
 	}
 
-	private void addRequiredJunitRuntimePlugins(ILaunchConfiguration configuration) throws CoreException {
-		Set<String> requiredPlugins = new LinkedHashSet<>(
-				JUnitLaunchConfigurationDelegate.getRequiredJunitRuntimePlugins(configuration));
-
-		if (fAllBundles.containsKey("junit-platform-runner")) { //$NON-NLS-1$
-			// add launcher and jupiter.engine to support @RunWith(JUnitPlatform.class)
-			requiredPlugins.add("junit-platform-launcher"); //$NON-NLS-1$
-			requiredPlugins.add("junit-jupiter-engine"); //$NON-NLS-1$
-		}
-
-		Set<BundleDescription> addedRequirements = new HashSet<>();
-		addAbsentRequirements(requiredPlugins, addedRequirements);
-
-		Set<BundleDescription> requirementsOfRequirements = DependencyManager
-				.findRequirementsClosure(addedRequirements);
-		Set<String> rorIds = requirementsOfRequirements.stream().map(BundleDescription::getSymbolicName)
-				.collect(Collectors.toSet());
-		addAbsentRequirements(rorIds, null);
-	}
-
-	private void addAbsentRequirements(Collection<String> requirements, Set<BundleDescription> addedRequirements)
-			throws CoreException {
-		for (String id : requirements) {
-			List<IPluginModelBase> models = fAllBundles.computeIfAbsent(id, k -> new ArrayList<>());
-			if (models.stream().noneMatch(m -> m.getBundleDescription().isResolved())) {
-				IPluginModelBase model = findRequiredPluginInTargetOrHost(id);
-				models.add(model);
-				BundleLauncherHelper.addDefaultStartingBundle(fModels, model);
-				if (addedRequirements != null) {
-					addedRequirements.add(model.getBundleDescription());
-				}
-			}
-		}
-	}
-
 	@Override
 	public String getJavaProjectName(ILaunchConfiguration configuration) throws CoreException {
 		return configuration.getAttribute(IJavaLaunchConfigurationConstants.ATTR_PROJECT_NAME, (String) null);
@@ -614,7 +582,8 @@ public class JUnitPluginLaunchConfigurationDelegate extends AbstractJavaLaunchCo
 		boolean isModularProject = JavaRuntime.isModularProject(getJavaProject(configuration));
 		String addOpensTargets;
 		if (isModularProject) {
-			if (getJUnitVersion(configuration) == JUnitVersion.JUNIT5) {
+			JUnitVersion jUnitVersion = getJUnitVersion(configuration);
+			if (jUnitVersion == JUnitVersion.JUNIT5 || jUnitVersion == JUnitVersion.JUNIT6) {
 				if (isOnModulePath(getJavaProject(configuration), "org.junit.jupiter.api.Test")) { //$NON-NLS-1$
 					addOpensTargets = "junit-platform-commons,ALL-UNNAMED"; //$NON-NLS-1$
 				} else {
@@ -1085,18 +1054,6 @@ public class JUnitPluginLaunchConfigurationDelegate extends AbstractJavaLaunchCo
 		return application;
 	}
 
-	private IPluginModelBase findRequiredPluginInTargetOrHost(String id) throws CoreException {
-		IPluginModelBase model = PluginRegistry.findModel(id);
-		if (model == null || !model.getBundleDescription().isResolved()) {
-			// prefer bundle from host over unresolved bundle from target
-			model = PDECore.getDefault().findPluginInHost(id);
-		}
-		if (model == null) {
-			abort(NLS.bind(Messages.JUnitPluginLaunchConfigurationDelegate_error_missingPlugin, id), null, IStatus.OK);
-		}
-		return model;
-	}
-
 	@Override
 	public String getProgramArguments(ILaunchConfiguration configuration) throws CoreException {
 		return LaunchArgumentsHelper.getUserProgramArguments(configuration);
